-- name: [CS] Hat kid
-- description: "I'm a time traveling explorer! No area is too dangerous for me"\n\n\\#6829A6\\This Pack requires Character Select\nto use as a Library!

--[[
    API Documentation for Character Select can be found below:
    https://github.com/Squishy6094/character-select-coop/blob/main/API-doc.md

    Use this if you're curious on how anything here works >v<
]]

local E_MODEL_hatkid = smlua_model_util_get_id("hatkid_geo")

local TEX_hatkid_ICON = get_texture_info("hatkidr-icon")

local TEXT_MOD_NAME = "The hatkid"

local VOICETABLE_hatkid = {
   --[CHAR_SOUND_OKEY_DOKEY] = 'StartLevel.ogg', -- Starting game
    [CHAR_SOUND_LETS_A_GO] = nil, -- Starting level
    [CHAR_SOUND_OOOF] = 'hurt_ow01.ogg',
    [CHAR_SOUND_OOOF2] = 'burnhurt_ack02.ogg',
    [CHAR_SOUND_WAH2] = 'HatKid_Woosh.ogg',
    [CHAR_SOUND_PUNCH_YAH] = 'attack_ho01.ogg', -- Punch 1
    [CHAR_SOUND_PUNCH_WAH] = 'attack_ya02.ogg', -- Punch 2
    [CHAR_SOUND_PUNCH_HOO] = 'HatKid_Woosh.ogg', -- Punch 3
    [CHAR_SOUND_YAH_WAH_HOO] = {'jump_1.ogg','jump_2.ogg'}, -- First/Second jump sounds
    [CHAR_SOUND_HOOHOO] = 'jump_2.ogg', -- Third jump sound
    [CHAR_SOUND_YAHOO_WAHA_YIPPEE] = 'jump_3.ogg', -- Triple jump sounds
    [CHAR_SOUND_UH] = 'wallbonk1.ogg', -- Wall bonk
    [CHAR_SOUND_UH2] = nil, -- Landing after long jump
    [CHAR_SOUND_UH2_2] = 'gtrabbin edge.ogg', -- Same sound as UH2; jumping onto ledge
    [CHAR_SOUND_HAHA] = 'HatKid_Haha.ogg', -- Landing triple jump
    [CHAR_SOUND_YAHOO] = 'HatKid_Booyaah.ogg', -- Long jump
    [CHAR_SOUND_HAHA_2] = 'HatKid_Haha.ogg',
    [CHAR_SOUND_DOH] = 'wallbonk1.ogg', -- Long jump wall bonk
    [CHAR_SOUND_WHOA] = 'gtrabbin edge.ogg', -- Grabbing ledge
    [CHAR_SOUND_EEUH] = 'Jumpedge.ogg', -- Climbing over ledge
    [CHAR_SOUND_WAAAOOOW] = 'Endless_Pit_Yell.ogg', -- Falling a long distance
    [CHAR_SOUND_TWIRL_BOUNCE] = 'jump_3.ogg', -- Bouncing off of a flower spring
    [CHAR_SOUND_GROUND_POUND_WAH] = nil, 
    [CHAR_SOUND_HRMM] = 'HatKid_Um.ogg', -- Lifting something
    [CHAR_SOUND_HERE_WE_GO] = 'HatKid_Awesome.ogg', -- Star get
    [CHAR_SOUND_SO_LONGA_BOWSER] = 'HatKid_Booyaah.ogg', -- Throwing Bowser
--DAMAGE
    [CHAR_SOUND_ATTACKED] = 'hurt_ow01.ogg', -- Damaged
    [CHAR_SOUND_PANTING] = 'NearDeath1.ogg', -- Low health
    [CHAR_SOUND_ON_FIRE] = 'burnhurt_ack02.ogg', -- Burned
--SLEEP SOUNDS
    [CHAR_SOUND_IMA_TIRED] = nil, -- Mario feeling tired
    [CHAR_SOUND_YAWNING] = 'hatkid_intro_yawn.ogg', -- Mario yawning before he sits down to sleep
    [CHAR_SOUND_SNORING1] = nil, -- Snore Inhale
    [CHAR_SOUND_SNORING2] = nil, -- Exhale
    [CHAR_SOUND_SNORING3] = nil, -- Sleep talking / mumbling
--COUGHING (USED IN THE GAS MAZE)
    [CHAR_SOUND_COUGHING1] = 'HatKid_Coughing.ogg', -- Cough take 1
    [CHAR_SOUND_COUGHING2] = 'HatKid_Coughing.ogg', -- Cough take 2
    [CHAR_SOUND_COUGHING3] = 'HatKid_Coughing.ogg', -- Cough take 3
--DEATH
    [CHAR_SOUND_DYING] = 'Death_Yell.ogg', -- Dying from damage
    [CHAR_SOUND_DROWNING] = nil, -- Running out of air underwater
    [CHAR_SOUND_MAMA_MIA] = 'HatKid_Uhhh.ogg' -- Booted out of level
}

local PALETTE_hatkid = {
    [PANTS]  = "FFEAAC",
    [SHIRT]  = "612589",
    [GLOVES] = "F59E2C",
    [SHOES]  = "81371B",
    [HAIR]   = "81371B",
    [SKIN]   = "FF6129",
    [CAP]    = "301A43",
}

local CAPTABLE_hatkid = {
    normal = smlua_model_util_get_id("hatkid_cap_normal_geo"),
    wing = smlua_model_util_get_id("hatkid_cap_wing_geo"),
    metal = smlua_model_util_get_id("hatkid_cap_metal_geo"),
    metalWing = smlua_model_util_get_id("hatkid_cap_wing_geo"),
}
--]]
if _G.charSelectExists then
    CT_CHAR = _G.charSelect.character_add("Hat Kid", "Humanoid Alien", "Made by @Asplatim on twitter", {r = 104, g = 41, b = 166}, E_MODEL_hatkid, CT_MARIO, TEX_hatkid_ICON)
     _G.charSelect.character_add_caps(E_MODEL_hatkid, CAPTABLE_hatkid)

    _G.charSelect.character_add_palette_preset(E_MODEL_hatkid, PALETTE_hatkid)

     --the following must be hooked for each character added

    _G.charSelect.character_add_voice(E_MODEL_hatkid, VOICETABLE_hatkid)
    hook_event(HOOK_CHARACTER_SOUND, function (m, sound)
        if _G.charSelect.character_get_voice(m) == VOICETABLE_hatkid then return _G.charSelect.voice.sound(m, sound) end
    end)
    hook_event(HOOK_MARIO_UPDATE, function (m)
        if _G.charSelect.character_get_voice(m) == VOICETABLE_hatkid then return _G.charSelect.voice.snore(m) end
    end)
else
    djui_popup_create("\\#ffffdc\\\n"..TEXT_MOD_NAME.."\nRequires the Character Select Mod\nto use as a Library!\n\nPlease turn on the Character Select Mod\nand Restart the Room!", 6)
end